@@ -5,3 +5,5 @@
 #undef HAVE_STPCPY
 #undef HAVE_LIBSM
 #undef HAVE_POPT
+#undef TARGET
+#undef CATALOG2
