@@ -58,8 +58,6 @@ enable_gnome_button_bar (GtkWidget * window, gpointer data)
     GNOMEUIINFO_ITEM_STOCK (N_("Edit categories"), N_("Edit categories"),
 			    cb_edit_categories,
 			    GNOME_STOCK_PIXMAP_PROPERTIES),
-    GNOMEUIINFO_ITEM_NONE (N_("Clean descriptions"), N_("Clean descriptions"),
-			   cb_clean_description),
     GNOMEUIINFO_ITEM_STOCK (N_("Preferences"), N_("Preferences"),
 			    cb_run_setup, GNOME_STOCK_PIXMAP_PREFERENCES),
     GNOMEUIINFO_ITEM_STOCK (N_("Find file"), N_("Find file"),
@@ -89,11 +87,11 @@ enable_gnome_button_bar (GtkWidget * window, gpointer data)
 
   memcpy (&(toolbar[3]), &(general_toolbar[0]), sizeof (GnomeUIInfo));
 
-  memcpy (&(toolbar[4]), &(general_toolbar[11]), sizeof (GnomeUIInfo));
-  memcpy (&(toolbar[5]), &(general_toolbar[8]), sizeof (GnomeUIInfo));
+  memcpy (&(toolbar[4]), &(general_toolbar[10]), sizeof (GnomeUIInfo));
+  memcpy (&(toolbar[5]), &(general_toolbar[7]), sizeof (GnomeUIInfo));
   memcpy (&(toolbar[6]), &(general_toolbar[0]), sizeof (GnomeUIInfo));
-  memcpy (&(toolbar[7]), &(general_toolbar[12]), sizeof (GnomeUIInfo));
-  memcpy (&(toolbar[8]), &(general_toolbar[13]), sizeof (GnomeUIInfo));
+  memcpy (&(toolbar[7]), &(general_toolbar[11]), sizeof (GnomeUIInfo));
+  memcpy (&(toolbar[8]), &(general_toolbar[12]), sizeof (GnomeUIInfo));
 
   gnome_app_create_toolbar_with_data (GNOME_APP (window), toolbar, NULL);
 
@@ -162,18 +160,6 @@ cb_edit_categories (GtkWidget * w, gpointer data)
     }
 }
 
-void
-cb_clean_description (GtkWidget * w, gpointer data)
-{
-  if (get_thread_status () == THREAD_SCAN_RUNNING_NO)
-    {
-      if (my_config->racine)
-	{
-	  clean_description (my_config->racine);
-	}
-    }
-}
-
 void
 cb_run_setup (GtkWidget * w, gpointer data)
 {
