@@ -92,6 +92,7 @@ ok_clicked (GtkWidget * w, gpointer data)
   GtkCTreeNode *gtknode;
   PIX *pix;
   GNode *tmpgn;
+  gboolean gc_descriptions_flag;
 
   gn = racine->selected_folder;
   fd = get_file_data_from_gnode (gn);
@@ -147,12 +148,16 @@ ok_clicked (GtkWidget * w, gpointer data)
     }
 
   /* Change the descriptions ? */
+  gc_descriptions_flag = FALSE;
   if (strcmp (entry_text3, EMPTY))
     {
       fd->description = description_add (racine->descriptions, entry_text3);
     }
   else
-    fd->description = 0;
+    {
+      fd->description = 0;
+      gc_descriptions_flag = TRUE;
+    }
   if ((is_file (racine->selected_folder) == FALSE)
       && (is_link (racine->selected_folder) == FALSE))
     {
@@ -164,6 +169,9 @@ ok_clicked (GtkWidget * w, gpointer data)
 			   GUINT_TO_POINTER (0 + fd->description));
 	}
     }
+  if (gc_descriptions_flag == TRUE)
+    description_garbage_collection ();
+
 
   /* Change the name ? */
   if (strcmp (fd->name->str, entry_text))
@@ -200,6 +208,7 @@ delete_folder (GtkWidget * w, FOLDER * racine)
   GNode *parent;
   parent = racine->selected_folder->parent;
   suppress_dir (racine->selected_folder);
+  description_garbage_collection ();
   list_folder (parent);
 }
 
