@@ -24,6 +24,8 @@
 #include <unistd.h>
 #include "folder.h"
 
+GPtrArray *new_descriptions;
+
 FILE_DATA *
 get_file_data_from_gnode (GNode * gn)
 {
@@ -547,3 +549,86 @@ make_disk_list (FOLDER * racine)
 			   _make_disk_list, &disk_list);
   return (disk_list.list);
 }
+
+gint _cmp_intptrs (gconstpointer a, gconstpointer b)
+{
+  if (GPOINTER_TO_UINT (a) < GPOINTER_TO_UINT (b))
+    return (-1);
+  if (GPOINTER_TO_UINT (a) > GPOINTER_TO_UINT (b))
+    return (+1);
+  return (0);
+}
+
+gboolean _test_description (GNode * gn, gpointer data)
+{
+  FILE_DATA *fd;
+  guint u = 0;
+  gpointer gp;
+
+  if (G_NODE_IS_ROOT (gn) == TRUE)
+    return (FALSE);
+  fd = get_file_data_from_gnode (gn);
+
+  u = fd->description;
+  if (u > 0)
+    {
+      if (g_tree_lookup ((GTree *) data, GUINT_TO_POINTER (u)) == NULL)
+	{
+	  printf ("test %d\n", u);
+	  g_ptr_array_add (new_descriptions,
+			   (gp =
+			    g_ptr_array_index (my_config->
+					       racine->descriptions, u - 1)));
+	  g_assert (gp != NULL);
+	  g_ptr_array_index (my_config->racine->descriptions, u - 1) = NULL;
+	  g_tree_insert ((GTree *) data, GUINT_TO_POINTER (u),
+			 GUINT_TO_POINTER (new_descriptions->len));
+	}
+    }
+  return (FALSE);
+}
+
+gboolean
+_adapt_description (GNode * gn, gpointer data)
+{
+  FILE_DATA *fd;
+  guint u = 0, nu;
+  if (G_NODE_IS_ROOT (gn) == TRUE)
+    return (FALSE);
+  fd = get_file_data_from_gnode (gn);
+  u = fd->description;
+  if (u > 0)
+    {
+      nu =
+	GPOINTER_TO_UINT (g_tree_lookup
+			  ((GTree *) data, GUINT_TO_POINTER (u)));
+      g_assert ((nu > 0) && (nu < 65535));
+      fd->description = nu;
+    }
+  return (FALSE);
+}
+
+void
+description_garbage_collection ()
+{
+  FOLDER *racine = my_config->racine;
+  GTree *corresp = g_tree_new (_cmp_intptrs);
+  GString *gs;
+  gint i;
+
+  new_descriptions = g_ptr_array_new ();
+  g_node_traverse (racine->tree,
+		   G_PRE_ORDER, G_TRAVERSE_ALL, -1, _test_description,
+		   corresp);
+  g_node_traverse (racine->tree, G_PRE_ORDER, G_TRAVERSE_ALL, -1,
+		   _adapt_description, corresp);
+  for (i = 0; i < racine->descriptions->len; i++)
+    {
+      if ((gs = g_ptr_array_index (racine->descriptions, i)))
+	{
+	  g_string_free (gs, TRUE);
+	}
+    }
+  g_ptr_array_free (racine->descriptions, FALSE);
+  racine->descriptions = new_descriptions;
+}
