@@ -155,8 +155,7 @@ traverse_add_file_to_clist (GNode * gn, gpointer data)
 /*****************************************************************************************/
 
 
-gint
-find_viewer (gpointer key, gpointer value, gpointer data)
+gint find_viewer (gpointer key, gpointer value, gpointer data)
 {
   struct extension_and_string *_find_ext = data;
   EXTENSIONS *e = value;
@@ -601,7 +600,7 @@ tree_pressed (GtkWidget * wid, GdkEventButton * event, gpointer data)
 	  gnome_popup_menu_do_popup (list_menu, NULL, NULL, event, racine);
 	}
     }
-  else if ((event->button == 1) && (event->type == GDK_2BUTTON_PRESS))
+  else if ((event->button == 1) )
     {
       x = event->x;
       y = event->y;
@@ -664,27 +663,6 @@ update_tree (FOLDER * racine)
   gtk_widget_show_all (racine->ctree);
 }
 
-void
-clean_description (FOLDER * racine)
-{
-  FILE_DATA *fd;
-  gint i;
-
-  for (i = 1; i < racine->datas->len; i++)
-    {
-      fd = g_ptr_array_index (racine->datas, i);
-      fd->description = 0;
-    }
-  for (i = 0; i < racine->descriptions->len; i++)
-    {
-      g_string_free (g_ptr_array_index (racine->descriptions, i), TRUE);
-      g_ptr_array_index (racine->descriptions, i) = NULL;
-    }
-  g_ptr_array_free (racine->descriptions, FALSE);
-  racine->descriptions = g_ptr_array_new ();
-  list_folder (racine->currently_displayed_gnode);
-}
-
 /* GNOME Menu */
 GnomeUIInfo file_menu[] = {
   GNOMEUIINFO_MENU_NEW_ITEM (N_("New catalog"), N_("New catalog"),
@@ -700,9 +678,6 @@ GnomeUIInfo file_menu[] = {
 
 GnomeUIInfo edit_menu[] = {
   GNOMEUIINFO_ITEM_NONE (N_("Edit categories"), NULL, cb_edit_categories),
-  GNOMEUIINFO_ITEM_NONE (N_("Clean descriptions"), NULL,
-			 cb_clean_description),
-  GNOMEUIINFO_SEPARATOR,
   GNOMEUIINFO_MENU_PREFERENCES_ITEM (cb_run_setup, NULL),
   GNOMEUIINFO_END
 };
@@ -746,16 +721,13 @@ build_gui ()
   enable_gnome_button_bar (main_window, NULL);
 
 /* Status and progress bar */
-  appbar1 = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_USER);
+  appbar1 = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_NEVER);
   gtk_widget_ref (appbar1);
   gtk_object_set_data_full (GTK_OBJECT (main_window), "appbar1", appbar1,
 			    (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (appbar1);
   gnome_app_set_statusbar (GNOME_APP (main_window), appbar1);
-  progress_setProgressBar (GTK_WIDGET
-			   (gnome_appbar_get_progress
-			    (GNOME_APPBAR (appbar1))));
-
+  progress_setGnomeAppBar (appbar1);
 
 /* Path entry */
   path_entry = gtk_entry_new_with_max_length (300);
@@ -789,4 +761,5 @@ build_gui ()
   gtk_widget_show (ctree_window);
 
   gtk_paned_add1 (GTK_PANED (hpaned), ctree_window);
+
 }
