@@ -30,8 +30,7 @@ static GtkWidget *fs;
  * It should better be called as a traversefunc with g_node_traverse
  */
 
-gboolean
-add_gnode_to_ctree (GNode * gn, gpointer data)
+gboolean add_gnode_to_ctree (GNode * gn, gpointer data)
 {
   FOLDER *racine = data;
   FILE_DATA *fd, *parent_fd, *child_fd;
