@@ -27,6 +27,10 @@
 #include "folder.h"
 #include "loadcat.h"
 
+#ifdef CATALOG2
+#include "load_oldcat.h"
+#endif
+
 GString *
 read_gstring (int fh)
 {
@@ -200,8 +204,11 @@ load_cat_from_file (char *filename, FOLDER * racine)
 {
   char fileformat[MAX_STRING_LENGTH];
   gint l, le;
+#ifdef CATALOG2
+  gint result;
+#endif
   int catalog;
-  gzFile gzcatalog;
+  gzFile gzcatalog = NULL;
 
 /* Test if the file exists */
   if ((g_file_test (filename, G_FILE_TEST_ISFILE)) != TRUE)
@@ -220,10 +227,10 @@ load_cat_from_file (char *filename, FOLDER * racine)
 
 /* Test if the length is big enough */
   l = lseek (catalog, 0, SEEK_END);
-  if (l < 8)
+  if (l < 9)
     {
       close (catalog);
-      ERROR_DIALOG ("File is not a GTKtalog file (v3 file format).",
+      ERROR_DIALOG ("File is not a GTKtalog file (Too Small !).",
 		    main_window);
       return (-1);
 
@@ -234,20 +241,60 @@ load_cat_from_file (char *filename, FOLDER * racine)
  * Older versions of gtktalog begin with "gtktalog"
  */
   l = lseek (catalog, 0, SEEK_SET);
-  read (catalog, fileformat, sizeof (gchar) * 8);
-  fileformat[8] = 0;
-  if (strcmp (fileformat, "gtktalog") == 0)
+  read (catalog, fileformat, sizeof (gchar) * 9);
+  fileformat[9] = 0;
+  if (strcmp (fileformat, "gtktalog2") == 0)
     {
+#ifdef CATALOG2
+      /* Try to load an gtktalog v2 */
+      gzcatalog = gzdopen (catalog, "rb");
+      result = load_oldfolder_tree (racine, gzcatalog);
+      gzclose (gzcatalog);
+      WARNING_DIALOG
+	("Warning: the code for loading an old catalog will not be maintained.\n"
+	 "It should not stay in gtktalog for a long time, "
+	 "so do not forget to save your converted catalogs.\n"
+	 "However, a converter exists and will be maintained in case "
+	 "you had forgotten to convert a catalog", main_window);
+      if (result)
+	{
+	  ERROR_DIALOG
+	    ("The loading of this old catalog has failed.\nInsure this is a good catalog and\nEmail the authors specifying the problem",
+	     main_window);
+	  return (0);
+	}
+
+      racine->is_modified = FALSE;
+      return (0);
+#else
+
       close (catalog);
+      /* FIXME: Remove this dialog box when the code is correct for links */
       ERROR_DIALOG
 	("File is seems to have been generated with a version older "
-	 "than 0.1.0 of GTKtalog. Formats are incompatibles. "
-	 "Send a mail to the authors to know what to do.", main_window);
+	 "than 0.1.0 of GTKtalog. Formats are incompatibles.\n"
+	 "Try './configure --enable-catalog2' then recompile gtktalog "
+	 "Or use the converter!",
+	 main_window);
       return (-1);
+
+#endif
+    }
+  else
+    {
+      /* File format prior to (at least 0.0.18) */
+      fileformat[8] = 0;
+      if (strcmp (fileformat, "gtktalog") == 0)
+	{
+	  ERROR_DIALOG
+	    ("File is seems to have been generated with a version older "
+	     "than 0.0.18 (at least) of GTKtalog. Formats are incompatibles. "
+	     "Send a mail to the authors to know what to do.", main_window);
+	  return (-1);
+	}
     }
 
-
-/* Test if this is a catalog in v3 format. */
+  /* Test if this is a catalog in v3 format. */
   l = lseek (catalog, 0, SEEK_SET);
   read (catalog, &le, sizeof (gint));
   l = GINT_FROM_LE (le);
