@@ -21,6 +21,10 @@
 
 #include "config_common.h"
 
+#ifdef CATALOG2
+	#include "load_oldcat.h"
+#endif
+
 GString *read_gstring(int fh);
 GString *gzread_gstring(gzFile fh);
 FILE_DATA *read_filedata(gzFile gzfh, int fh);
