@@ -63,7 +63,7 @@ main (int argc, char *argv[])
   GString *_filename = NULL;
   GString *_geometry = NULL;
   gint wx, wy, ww, wh;
-  gchar c;
+  int c;
 
 
   bindtextdomain (PACKAGE, GNOMELOCALEDIR);
