@@ -27,7 +27,8 @@
 #include "config_common.h"
 
 static gchar ALL_DISKS[] = N_("All disks");
-static gchar ALL_CATEGORIES[] = N_("All");
+static gchar ALL_CATEGORIES[] = N_("(All)");
+static gchar CATEGORY_NONE[] = N_("(None)");
 static GtkWidget *report_dialog_window;
 static GtkWidget *disk_combo;
 static GtkWidget *cat_combobox;
@@ -123,8 +124,7 @@ _report_cats (GNode * gn, gpointer data)
 
 }
 
-gboolean
-generate_cat_report (FOLDER * racine, FILE * file)
+gboolean generate_cat_report (FOLDER * racine, FILE * file)
 {
   gint i;
   gint j;
@@ -138,9 +138,17 @@ generate_cat_report (FOLDER * racine, FILE * file)
 	      (GTK_ENTRY (GTK_COMBO (cat_combobox)->entry)));
   cat_to_report = -2;
   if (strlen (the_cat) == 0)
-    cat_to_report = 0;
+    {
+      cat_to_report = 0;
+    }
+  else if (strcmp (the_cat, CATEGORY_NONE) == 0)
+    {
+      cat_to_report = 0;
+    }
   else if (strcmp (the_cat, ALL_CATEGORIES) == 0)
-    cat_to_report = -1;
+    {
+      cat_to_report = -1;
+    }
   else
     {
       for (i = 1; i <= racine->categories->len; i++)
@@ -308,9 +316,17 @@ generate_file_report (FOLDER * racine, FILE * file)
 	      (GTK_ENTRY (GTK_COMBO (cat_combobox)->entry)));
   cat_to_report = -2;
   if (strlen (the_cat) == 0)
-    cat_to_report = 0;
+    {
+      cat_to_report = 0;
+    }
+  else if (strcmp (the_cat, CATEGORY_NONE) == 0)
+    {
+      cat_to_report = 0;
+    }
   else if (strcmp (the_cat, ALL_CATEGORIES) == 0)
-    cat_to_report = -1;
+    {
+      cat_to_report = -1;
+    }
   else
     {
       for (i = 1; i <= racine->categories->len; i++)
@@ -546,6 +562,7 @@ open_report_dialog (FOLDER * racine)
 
   cat_list = cat_list = make_categories_list (racine);
   cat_list = g_list_append (cat_list, ALL_CATEGORIES);
+  cat_list = g_list_append (cat_list, CATEGORY_NONE);
 
   gtk_combo_set_popdown_strings (GTK_COMBO (cat_combobox), cat_list);
   gtk_entry_set_editable (GTK_ENTRY (GTK_COMBO (cat_combobox)->entry), FALSE);
