@@ -18,6 +18,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -46,7 +47,8 @@ write_gstring (GString * g, int fh)
 	}
       else
 	{
-	  write (fh, &(g->len), sizeof (gint));
+	  i = GINT_TO_LE (g->len);
+	  write (fh, &i, sizeof (gint));
 	  write (fh, (g->str), sizeof (gchar) * g->len);
 	}
     }
@@ -68,7 +70,8 @@ gzwrite_gstring (GString * g, gzFile fh)
 	}
       else
 	{
-	  gzwrite (fh, &(g->len), sizeof (gint));
+	  i = GINT_TO_LE (g->len);
+	  gzwrite (fh, &i, sizeof (gint));
 	  gzwrite (fh, (g->str), sizeof (gchar) * g->len);
 	}
     }
@@ -77,13 +80,22 @@ gzwrite_gstring (GString * g, gzFile fh)
 void
 write_filedata (FILE_DATA * d, gzFile fh)
 {
+  guint32 le32;
+  guint16 le16;
+  guint le;
+
   g_assert (d != NULL);
   gzwrite_gstring (d->name, fh);
-  gzwrite (fh, &(d->taille), sizeof (guint32));
-  gzwrite (fh, &(d->type), sizeof (guint));
-  gzwrite (fh, &(d->date), sizeof (time_t));
-  gzwrite (fh, &(d->categorie), sizeof (guint16));
-  gzwrite (fh, &(d->description), sizeof (guint16));
+  le32 = GUINT32_TO_LE (d->taille);
+  gzwrite (fh, &le32, sizeof (guint32));
+  le = GUINT_TO_LE (d->type);
+  gzwrite (fh, &le, sizeof (guint));
+  le32 = GUINT32_TO_LE (d->date);
+  gzwrite (fh, &le32, sizeof (guint32));
+  le16 = GUINT16_TO_LE (d->categorie);
+  gzwrite (fh, &le16, sizeof (guint16));
+  le16 = GUINT16_TO_LE (d->description);
+  gzwrite (fh, &le16, sizeof (guint16));
   gzwrite_gstring (d->information, fh);
 }
 
@@ -118,9 +130,11 @@ save_cat_to_file (char *filename, FOLDER * racine)
 {
   gint i, id;
   gint nb_datas = 0;
+  gint le;
   int catalog;
 //  gzFile gzcatalog;
   GString *header;
+  gchar mode[] = "wb9";
 
   if ((g_file_test (filename, G_FILE_TEST_ISFILE)) == TRUE)
     {
@@ -143,11 +157,14 @@ save_cat_to_file (char *filename, FOLDER * racine)
   g_string_free (header, TRUE);
 
 /* reopen with zlib */
-  gzcatalog = gzdopen (catalog, "wb9");
+  g_assert((my_config->compression_level>=0) && (my_config->compression_level<=9));
+  sprintf(mode, "wb%d", my_config->compression_level);
+  gzcatalog = gzdopen (catalog, mode);
 
   /* descriptions */
   nb_datas = racine->descriptions->len;
-  gzwrite (gzcatalog, &nb_datas, sizeof (gint));
+  le = GINT_TO_LE (nb_datas);
+  gzwrite (gzcatalog, &le, sizeof (gint));
   for (i = 0; i < nb_datas; i++)
     {
       gzwrite_gstring (g_ptr_array_index (racine->descriptions, i),
@@ -157,7 +174,8 @@ save_cat_to_file (char *filename, FOLDER * racine)
 
   /* categories */
   nb_datas = racine->categories->len;
-  gzwrite (gzcatalog, &nb_datas, sizeof (gint));
+  le = GINT_TO_LE (nb_datas);
+  gzwrite (gzcatalog, &le, sizeof (gint));
   for (i = 0; i < nb_datas; i++)
     {
       gzwrite_gstring (g_ptr_array_index (racine->categories, i), gzcatalog);
