@@ -47,18 +47,10 @@ start_add_disk (char *foldername, char *diskname, FOLDER * racine)
   set_local_disk_name (diskname);
   set_local_folder_name (foldername);
 
+  do_not_forget_to_mount(FALSE);
   set_thread_status_to_running ();
   progress_timeout (NULL);
   do_not_forget_to_umount (FALSE);
-/* Initialize the status bar */
-  if (my_config->use_du_s == TRUE)
-    {
-      progress_setTotal (du_s (foldername));
-    }
-  else
-    {
-      progress_setTotal (0);
-    }
   if (pthread_create (&thread1, NULL, start_thread_scan, racine) < 0)
     {
       reinit_thread_status ();
