@@ -42,6 +42,7 @@ static GtkWidget *eject_entry;
 static GtkWidget *checkbutton_dus;
 static GtkWidget *checkbutton_warnMount;
 static GtkWidget *checkbutton_eject;
+static GtkWidget *compression_level;
 static GdkPixmap *on_pix;
 static GdkPixmap *off_pix;
 static GtkStyle *style;
@@ -140,6 +141,9 @@ setup_ok_clicked (GtkWidget * w, gpointer data)
   my_config->warn_mount =
     (gboolean) (gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON (checkbutton_warnMount)));
+  my_config->compression_level = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(compression_level));
+
+
 
   conf_file = g_string_new (g_get_home_dir ());
   if (conf_file->len < 1)
@@ -205,6 +209,9 @@ setup_ok_clicked (GtkWidget * w, gpointer data)
 	  fprintf (f, _("# Eject the disk after a fast scan\n"));
 	  fprintf (f, "OptionEject %s\n",
 		   (my_config->eject_disk ? "True" : "False"));
+	  fprintf (f, _("# Compression level for saving files\n"));
+	  fprintf (f, "CompressionLevel %d\n",
+		   (my_config->compression_level));
 
 	  fclose (f);
 	}
@@ -557,6 +564,8 @@ run_setup ()
   GtkWidget *edit_button;
   GtkWidget *vbox2, *vbox3;
   GtkWidget *scrolled_window;
+  GtkWidget *compression_level_label;
+  GtkAdjustment *compression_level_adj;
   gchar *titles[6] = { N_("State"),
     N_("File type"),
     N_("Plugin"),
@@ -848,6 +857,21 @@ run_setup ()
   gtk_widget_show (checkbutton_eject);
   gtk_box_pack_start (GTK_BOX (vbox3), checkbutton_eject, FALSE, FALSE, 0);
 
+  /* Option for compression level */
+  hbox = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox3), hbox, FALSE, FALSE, 0);
+  gtk_widget_show (hbox);
+  
+  compression_level_label =
+    gtk_label_new (_("Compression level"));
+  gtk_widget_show (compression_level_label);
+  gtk_box_pack_start (GTK_BOX (hbox), compression_level_label, FALSE, FALSE, 0);
+
+  compression_level_adj = (GtkAdjustment *)gtk_adjustment_new (9, 0, 9, 1, 1, 9);
+  compression_level = gtk_spin_button_new (GTK_ADJUSTMENT (compression_level_adj), 1, 0);
+  gtk_widget_show (compression_level);
+  gtk_box_pack_start (GTK_BOX (hbox), compression_level, FALSE, FALSE, 0);
+
 
 /*******************************************************************************************/
   /* Bottom buttons */
